Logo
Explore Help
Sign In
ODFstudio/odfstudio
Watch 2
Star 0
Fork 0
Code Issues Packages Activity
Files
0efccbc58b41008b03f5b1ecc0a97cfcd1d4eafd
odfstudio/xmloff/source
T
History
Noel Grandin 349919440b tdf#107592 Impress PPS save to ODP slow
Takes the time from 20s to 5s on my PC.

Change-Id: Iea7a94ee9fbe068b69a770fd9201e73646be59b9
Reviewed-on: https://gerrit.libreoffice.org/72140
Tested-by: Jenkins
Reviewed-by: Noel Grandin <noel.grandin@collabora.co.uk>
2019-05-13 13:23:00 +02:00
..
chart
fix wrong SET/QUERY flags passed to uno::Reference
2019-05-13 08:15:27 +02:00
core
xmloff: create XMLImpressSettingsExportOasis instances with an uno constructor
2019-05-09 08:57:49 +02:00
draw
fix wrong SET/QUERY flags passed to uno::Reference
2019-05-13 08:15:27 +02:00
forms
Use hasElements to check Sequence emptiness in [v-x]*
2019-05-02 09:53:48 +02:00
meta
Use hasElements to check Sequence emptiness in [v-x]*
2019-05-02 09:53:48 +02:00
script
loplugin:sequentialassign in writerfilter..xmlsecurity
2019-04-15 08:38:02 +02:00
style
tdf#107592 Impress PPS save to ODP slow
2019-05-13 13:23:00 +02:00
table
fix wrong SET/QUERY flags passed to uno::Reference
2019-05-13 08:15:27 +02:00
text
fix wrong SET/QUERY flags passed to uno::Reference
2019-05-13 08:15:27 +02:00
token
sw btlr writing mode: implement ODF filter
2019-02-13 15:17:34 +01:00
transform
Use hasElements to check Sequence emptiness in [v-x]*
2019-05-02 09:53:48 +02:00
xforms
tdf#63640 FILEOPEN/FILESAVE: particular .odt loads/saves very slow, part4
2019-04-29 08:31:21 +02:00
Powered by Gitea Version: 1.27.3 Page: 363ms Template: 11ms
Auto
English
Bahasa Indonesia Deutsch English Español Français Gaeilge Italiano Latviešu Magyar nyelv Nederlands Polski Português de Portugal Português do Brasil Suomi Svenska Türkçe Čeština Ελληνικά Български Русский Українська فارسی മലയാളം 日本語 简体中文 繁體中文(台灣) 繁體中文(香港) 한국어
Licenses API